/*
 *  Simbad - Robot Simulator
 *  Copyright (C) 2004 Louis Hugues
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, 
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 -----------------------------------------------------------------------------
 * $Author: sioulseuguh $ 
 * $Date: 2005/01/08 16:51:30 $
 * $Revision: 1.3 $
 * $Source: /cvsroot/simbad/src/simbad/gui/Console.java,v $
 */
package simbad.gui;
import java.awt.Container;
import java.awt.Font;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Map.Entry;
import java.util.Scanner;

import javax.swing.JInternalFrame;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

import jeu.Score;


/**
 * Récupère un fichier de score, affiche les scores de toutes les parties puis stocke le score
 * de la partie actuelle.
 * @author Louis-Pierre Aubert
 * @version 2018-21-12
 */
public class ScoreboardWindow extends JInternalFrame {
	
    ArrayList<Score>          scores;
	JTextArea                 jTextArea;
    JScrollPane               jScrollPane;
	
	public ScoreboardWindow ( int sizex, int sizey)
	{
		super("Scoreboard");
	    createGUI();
	    this.setFocusable(false);
	    setSize(sizex, sizey);
	    
	}

	private void createGUI()
	{	
		// Initialisation des variables
		this.scores = new ArrayList<Score>();
		
    	// Création des composants de l'interface.
		this.jTextArea   = new JTextArea();
    	this.jTextArea.setEditable(false);
    	this.jScrollPane = new JScrollPane(this.jTextArea);
    	this.add(this.jScrollPane);
    	
    	// Lecture et affichage des scores.
    	InputStream       ips  = this.getClass().getResourceAsStream("/scores.data");
    	InputStreamReader ipsr = new InputStreamReader(ips);
    	Scanner           sc   = new Scanner(ipsr);
    	
    	this.ajouterTexte( String.format( " %-30s | %-20s \n", "Player", "Score" )  );
    	this.ajouterTexte( "-----------------------------------------------------\n");
    	
    	while ( sc.hasNextLine() )
    	{
    		//System.out.println( "[DEBUG] " + sc.nextLine() );
    		this.scores.add( new Score( sc.next(), sc.nextInt() ) );
    	}
    	
    	this.updateScoreboard();
    	
	}
	
	public void updateScoreboard ()
	{
		this.scores.sort(null);
		
		for ( Score score : this.scores )
    	{
    		String nomJoueur = score.getNomJoueur();
    		int nbPoints = score.getScore();
			String ligneScore = String.format( "%"+(nomJoueur.length()-20)+"s | %-20s \n", score.getNomJoueur() , score.getScore() );
    		this.ajouterTexte( ligneScore );
    	}
		
	}
	
	public void addScore ( Score score )
	{
		this.scores.add(score);
		
		// Lecture et affichage des scores.
    	InputStream       ips  = this.getClass().getResourceAsStream("/scores.data");
    	
    	
		
	}
	
	/** Ajoute du texte dans la zone de texte ( jTextArea ).
	 * @param texte
	 * @return String ( pour debug avec System.out.println )
	 */
	private String ajouterTexte ( String texte )
	{
		this.jTextArea.setText( this.jTextArea.getText() + texte );
		return this.jTextArea.getText();
	}
	
	
	
}